@@ -1,10 +1,12 @@
 # coding: utf-8
 
+from operator  import mul, add
+from functools import reduce
+
 from sympy import Dummy
 from sympy import Matrix, ImmutableDenseMatrix
 from sympy.core import Basic, S
 from sympy.core import Expr, Add, Mul
-from sympy.core.expr import AtomicExpr
 from sympy.core.numbers import Zero as sy_Zero
 from sympy.core.containers import Tuple
 from sympy.core.compatibility import is_sequence
@@ -17,22 +19,35 @@ from sympde.calculus import Grad, Hessian
 from sympde.topology import BasicDomain, Union
 from sympde.topology import NormalVector
 from sympde.topology import Boundary, Interface, Domain, InteriorDomain
-from sympde.topology.space import ScalarFunctionSpace
-from sympde.topology.space import ProductSpace
 from sympde.topology.space import ScalarTestFunction
 from sympde.topology.space import VectorTestFunction
 from sympde.topology.space import Trace, trace_0, trace_1
-from sympde.topology.space import ScalarField, VectorField
 
 from .errors import UnconsistentLinearExpressionError
 from .basic  import BasicForm
 from .basic  import BasicExpr
 from .basic  import _sanitize_arguments
-from sympy   import cacheit
 
-from operator  import mul, add
-from functools import reduce
+__all__ = (
+    'BilinearForm',
+    'Functional',
+    'IntAdd',
+    'Integral',
+    'LinearExpr',
+    'LinearForm',
+    'Norm',
+#
+    '_get_domain',
+    'add_int',
+    'expand',
+    'integral',
+    'is_linear_expression',
+    'linearize',
+    'mul_add',
+    'mul_integral',
+)
 
+#==============================================================================
 class IntAdd(Add):
     _op_priority  = 20
     def __new__(cls, *args, **options):
@@ -154,12 +169,19 @@ class Integral(CalculusFunction):
         if isinstance(domain, Union):
             exprs = [cls(expr, d) for d in domain]
             return IntAdd(*exprs)
+
         elif isinstance(domain, Domain):
             interiors = domain.interior if isinstance(domain.interior, Union) else [domain.interior]
             exprs = [cls(expr, d) for d in interiors]
             return IntAdd(*exprs)
+
         elif isinstance(domain, Boundary):
-            expr = cls.subs_boundary_expr(expr, domain)
+            #------------------------------------------------------------
+            # NOTE [YG, 27.01.2021]:
+            #   we stop using Traces in the boundary integrals because of
+            #   an error that arises when using cross(v, nn).
+            #------------------------------------------------------------
+#            expr = cls.subs_boundary_expr(expr, domain)
             obj = CalculusFunction.__new__(cls, expr, domain)
             obj.is_boundary_integral = True
 
@@ -170,6 +192,7 @@ class Integral(CalculusFunction):
         elif isinstance(domain, InteriorDomain):
             obj = CalculusFunction.__new__(cls, expr, domain)
             obj.is_domain_integral = True
+
         else:
             raise TypeError(domain)
 
@@ -228,14 +251,10 @@ class Integral(CalculusFunction):
 
     @classmethod
     def subs_boundary_expr(cls, expr, domain):
-        atoms_1 = list(expr.atoms(Dot,Trace))
 
-        for i in range(len(atoms_1)):
-            a = atoms_1[i]
-            if isinstance(a, Dot):
-                if not isinstance(a.args[0], NormalVector):
-                    if not isinstance(a.args[1], NormalVector):
-                        atoms_1.remove(a)
+        atoms_1 = [*expr.atoms(Trace)] + [a for a in expr.atoms(Dot) \
+                                       if isinstance(a.args[0], NormalVector) \
+                                       or isinstance(a.args[1], NormalVector)]
 
         subs_1  = {a:Dummy() for a in atoms_1}
         expr, _ = expr._xreplace(subs_1)
@@ -273,7 +292,7 @@ class Functional(BasicForm):
     def __new__(cls, expr, domain, evaluate=True, **options):
 
         # compute dim from fields if available
-        ls = tuple(expr.atoms(ScalarField, VectorField, ScalarTestFunction, VectorTestFunction))
+        ls = tuple(expr.atoms(ScalarTestFunction, VectorTestFunction))
         if ls:
             F = ls[0]
             space = F.space
